-------------------------------------
pirt.interp - Interpolation functions
-------------------------------------

.. automodule:: pirt.interp


Interpolation by warping and projecting
---------------------------------------

.. autofunction:: pirt.warp
.. autofunction:: pirt.awarp
.. autofunction:: pirt.project
.. autofunction:: pirt.aproject


Deforming
---------

.. autofunction:: pirt.deform_backward
.. autofunction:: pirt.deform_forward


High level functions
--------------------

.. autofunction:: pirt.resize
.. autofunction:: pirt.imresize
.. autofunction:: pirt.zoom
.. autofunction:: pirt.imzoom


Helper functions
----------------

.. autofunction:: pirt.get_cubic_spline_coefs
.. autofunction:: pirt.meshgrid
.. autofunction:: pirt.make_samples_absolute


Sampling a 2D slice in a 3D volume
----------------------------------

.. autoclass:: SliceInVolume
    :members:
